@@ -264,7 +264,7 @@ class Person(Model, TsTrait):
 
 
 class User(TgUser, TsTrait):
-    status: UserStatus = IntEnumField(UserStatus, default=UserStatus.SLEEP)
+    status: UserStatus = IntEnumField(UserStatus, null=True)
     person: OneToOneRelation[Person] = OneToOneField("models.Person", "user", on_update=CASCADE)
     person_id: int
     ref: ForeignKeyNullableRelation["User"] = ForeignKeyField("models.User", "proteges", on_update=CASCADE, null=True)
@@ -584,6 +584,12 @@ class Pm(Model):
         table_description = "Payment methods"
         unique_together = (("norm", "country_id"), ("alias", "country_id"))
 
+    def client(self, bot):
+        module_name = f"xync_client.Pms.{self.norm.capitalize()}"
+        __import__(module_name)
+        client = sys.modules[module_name].Client
+        return client(self)
+
     # class PydanticMeta(Model.PydanticMeta):
     #     max_recursion = 3
     #     backward_relations = True
@@ -1145,7 +1151,6 @@ class Transfer(Model):
     # pm: ForeignKeyRelation["Pm"] = ForeignKeyField("models.Pm", "transfers", on_update=CASCADE)
     # pm_id: int
     created_at: datetime | None = DatetimeSecField(auto_now_add=True)
-    accepted_at: datetime | None = DatetimeSecField(null=True)
 
     # class Meta:
     #     unique_together = (("pmid", "pm_id"),)
@@ -1178,6 +1183,7 @@ class TopUpAble(Model):
     pm_id: int
     url: str = CharField(127)
     auth: dict = JSONField(default={})
+    fee: int = SmallIntField(default=0)  # /10_000
 
 
 class TopUp(Model):
